summaryrefslogtreecommitdiffstats
path: root/kalarm/messagewin.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
commit716a5de8870d7c02bb4d0aed72f30291b17b763a (patch)
tree29e58b213ead28151ccf7eb33d12c968ea844120 /kalarm/messagewin.cpp
parent0e00c0a86a4c9d7e80c7b66d91940cc7dcb79f78 (diff)
downloadtdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.tar.gz
tdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kalarm/messagewin.cpp')
-rw-r--r--kalarm/messagewin.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kalarm/messagewin.cpp b/kalarm/messagewin.cpp
index 4849e533..c1109b9d 100644
--- a/kalarm/messagewin.cpp
+++ b/kalarm/messagewin.cpp
@@ -650,7 +650,7 @@ void MessageWin::setRemainingTextMinute()
else if (mins % 60 == 1)
text = i18n("in 1 hour 1 minute's time", "in %n hours 1 minute's time", mins/60);
else
- text = i18n("in 1 hour %1 minutes' time", "in %n hours %1 minutes' time", mins/60).tqarg(mins%60);
+ text = i18n("in 1 hour %1 minutes' time", "in %n hours %1 minutes' time", mins/60).arg(mins%60);
mRemainingText->setText(text);
}
@@ -859,7 +859,7 @@ void MessageWin::slotPlayAudio()
kdError(5950) << "MessageWin::playAudio(): Open failure: " << mAudioFile << endl;
if (!haveErrorMessage(ErrMsg_AudioFile))
{
- KMessageBox::error(this, i18n("Cannot open audio file:\n%1").tqarg(mAudioFile));
+ KMessageBox::error(this, i18n("Cannot open audio file:\n%1").arg(mAudioFile));
clearErrorMessage(ErrMsg_AudioFile);
}
return;
@@ -882,7 +882,7 @@ void MessageWin::slotPlayAudio()
kdWarning(5950) << "Unable to set master volume (KMix: " << mKMixError << ")\n";
if (!haveErrorMessage(ErrMsg_Volume))
{
- KMessageBox::information(this, i18n("Unable to set master volume\n(Error accessing KMix:\n%1)").tqarg(mKMixError),
+ KMessageBox::information(this, i18n("Unable to set master volume\n(Error accessing KMix:\n%1)").arg(mKMixError),
TQString(), TQString::fromLatin1("KMixError"));
clearErrorMessage(ErrMsg_Volume);
}
@@ -1207,7 +1207,7 @@ TQSize MessageWin::sizeHint() const
if (!mWinModule)
mWinModule = new KWinModule(0, KWinModule::INFO_DESKTOP);
TQSize frame = frameGeometry().size();
- TQSize contents = tqgeometry().size();
+ TQSize contents = geometry().size();
TQSize desktop = mWinModule->workArea().size();
TQSize maxSize(desktop.width() - (frame.width() - contents.width()),
desktop.height() - (frame.height() - contents.height()));
@@ -1246,10 +1246,10 @@ void MessageWin::showEvent(TQShowEvent* se)
* To achieve this, move the window so that the OK button is as far away
* from the cursor as possible. If the buttons are still too close to the
* cursor, disable the buttons for a short time.
* N.B. This can't be done in show(), since the tqgeometry of the window
* is not known until it is displayed. Unfortunately by moving the
* window in showEvent(), a flicker is unavoidable.
* See the TQt documentation on window tqgeometry for more details.
*/
// PROBLEM: The frame size is not known yet!
@@ -1267,7 +1267,7 @@ void MessageWin::showEvent(TQShowEvent* se)
desk &= dw->screenGeometry(dw->screenNumber(cursor));
TQRect frame = frameGeometry();
- TQRect rect = tqgeometry();
+ TQRect rect = geometry();
// Find the offsets from the outside of the frame to the edges of the OK button
TQRect button(mOkButton->mapToParent(TQPoint(0, 0)), mOkButton->mapToParent(mOkButton->rect().bottomRight()));
int buttonLeft = button.left() + rect.left() - frame.left();
@@ -1282,7 +1282,7 @@ void MessageWin::showEvent(TQShowEvent* se)
// Find the enclosing rectangle for the new button positions
// and check if the cursor is too near
- TQRect buttons = mOkButton->tqgeometry().unite(mKAlarmButton->tqgeometry());
+ TQRect buttons = mOkButton->geometry().unite(mKAlarmButton->geometry());
buttons.moveBy(rect.left() + x - frame.left(), rect.top() + y - frame.top());
int minDistance = proximityMultiple * mOkButton->height();
if ((abs(cursor.x() - buttons.left()) < minDistance
@@ -1246,10 +1246,10 @@ void MessageWin::showEvent(TQShowEvent* se)
* from the cursor as possible. If the buttons are still too close to the
* cursor, disable the buttons for a short time.
- * N.B. This can't be done in show(), since the tqgeometry of the window
+ * N.B. This can't be done in show(), since the geometry of the window
* is not known until it is displayed. Unfortunately by moving the
* window in showEvent(), a flicker is unavoidable.
@@ -1246,10 +1246,10 @@ void MessageWin::showEvent(TQShowEvent* se)
* is not known until it is displayed. Unfortunately by moving the
* window in showEvent(), a flicker is unavoidable.
- * See the TQt documentation on window tqgeometry for more details.
+ * See the TQt documentation on window geometry for more details.
*/
// PROBLEM: The frame size is not known yet!